@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2020 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2023 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -361,7 +361,10 @@ class X2GoTerminalSession(object):
         self.params.geometry = str(geometry)
         self.params.link = str(link)
         self.params.pack = str(pack)
-        self.params.dpi = str(dpi)
+        if dpi:
+            self.params.dpi = str(dpi)
+        else:
+            self.params.dpi = ''
         self.params.cache_type = str(cache_type)
         self.params.session_type = str(session_type)
         self.params.kbtype = str(kbtype)
@@ -396,7 +399,10 @@ class X2GoTerminalSession(object):
 
         self.profile_name = profile_name
         self.set_session_title = set_session_title
-        self.session_title = session_title
+        if session_title:
+            self.session_title = session_title
+        else:
+            self.session_title = ''
         self.session_window = None
 
         # auto-detect graphical proxy/kdrive backend?
