@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2020 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2023 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -81,7 +81,7 @@ elif X2GOCLIENT_OS == "Linux":
     SUPPORTED_MIMEBOX = True
     SUPPORTED_TELEKINESIS = True
 
-elif X2GOCLIENT_OS == "Mac":
+elif X2GOCLIENT_OS == "Darwin":
     ROOT_DIR = '/'
     ETC_DIR = os.path.join(ROOT_DIR, 'etc', 'x2goclient')
     import getpass
