@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2020 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2023 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -57,7 +57,7 @@ class X2GoLogger(object):
     tag = ''
     progpid = -1
     level = -1
-    destination = sys.stderr
+    destination = sys.stdout
 
     _loglevel_NAMES = {8: 'error',
                    16: 'warn',
