@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2020 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2023 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -330,6 +330,7 @@ def x2go_rev_forward_channel_handler(chan=None, addr='', port=0, parent_thread=N
     logger('Connected! Reverse tunnel open %r -> %r -> %r' % (chan.origin_addr,
                                                               chan.getpeername(), (addr, port)),
                                                               loglevel=log.loglevel_INFO)
+    n = 0
     while parent_thread._accept_channels:
         r, w, x = select.select([fw_socket, chan], [], [])
         try:
@@ -345,6 +346,9 @@ def x2go_rev_forward_channel_handler(chan=None, addr='', port=0, parent_thread=N
                 fw_socket.send(data)
         except socket.error as e:
             logger('Reverse tunnel %s encoutered socket error: %s' % (chan, str(e)), loglevel=log.loglevel_WARN)
+            n += 1
+            if n >= 1024:
+                break
 
     chan.close()
     fw_socket.close()
