@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2010-2020 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
+# Copyright (C) 2010-2023 by Mike Gabriel <mike.gabriel@das-netzwerkteam.de>
 #
 # Python X2Go is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published by
@@ -333,8 +333,12 @@ def _convert_SessionProfileOptions_2_SessionParams(options):
     if not _params['kblayout'].strip(): _params['kblayout'] = 'null'
     if not _params['kbvariant'].strip(): _params['kbvariant'] = 'null'
 
+    # This might fire back on us some time...
+    # We need to set 'dpi' in _params as otherwise, it won't be overridable via method parameters
+    # X2GoSessionRegistry.register(). However, setting 'dpi' to a default value is different from
+    # not setting it... Let's see...
     if not options['setdpi']:
-        del _params['dpi']
+        _params['dpi'] = _X2GO_SESSIONPROFILE_DEFAULTS['dpi']
     del _params['setdpi']
 
     if options['sshproxysameuser']:
